@@ -49,6 +49,15 @@ activate_action_play (GtkAction *action,
 }
 
 
+void
+activate_action_play_selected (GtkAction *action, 
+			       gpointer   data)
+{
+	GooWindow *window = data;
+	goo_window_play_selected (window);
+}
+
+
 void
 activate_action_pause (GtkAction *action,
 		       gpointer   data)
@@ -133,7 +142,7 @@ activate_action_about (GtkAction *action,
 		return;
 	}
 
-	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/goo.png", NULL);
+	logo = gdk_pixbuf_new_from_file (PIXMAPSDIR "/goobox.png", NULL);
 	about = gnome_about_new (_("Goobox"), 
 				 VERSION,
 				 "Copyright \xc2\xa9 2004 Free Software Foundation, Inc.",
